==> gwenview_25.08.2.orig.tar.xz: gwenview-25.08.2/part/gvpart.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Gwenview Image Viewer
Name[ar]=جوِينفيو مستعرض الصورة
Name[az]=Gwenview Şəkilə Baxış Vasitəsi
Name[be]=Праграма для прагляду выяў Gwenview
Name[bg]=Програма за снимки Gwenview
Name[bs]=Gvenview prikazivač slika
Name[ca]=Visualitzador d'imatges Gwenview
Name[ca@valencia]=Visor d'imatges Gwenview
Name[cs]=Prohlížeč obrázků Gwenview
Name[da]=Gwenview billedfremviser
Name[de]=Gwenview Bildbetrachter
Name[el]=Προβολέας εικόνων Gwenview
Name[en_GB]=Gwenview Image Viewer
Name[eo]=Gwenview Bildrigardilo
Name[es]=Visor de imágenes Gwenview
Name[et]=Gwenview pildinäitaja
Name[eu]=Gwenview irudi erakuslea
Name[fa]=مشاهده‌گر تصویر Gwenview
Name[fi]=Gwenview-kuvankatselin
Name[fr]=Afficheur d'images Gwenview
Name[ga]=Amharcán Íomhánna Gwenview
Name[gl]=Visor de imaxes Gwenview
Name[he]=מציג התמונות Gwenview
Name[hi]=ग्वेन-व्यू छवि प्रदर्शक
Name[hne]=ग्वेन-व्यू फोटू प्रदर्सक
Name[hr]=Preglednik slika Gwenview
Name[hsb]=Gwenview wobhladowar za wobrazy
Name[hu]=Gwenview képnézegető
Name[ia]=Visor de imagine Gwenview
Name[id]=Penampil Citra Gwenview
Name[ie]=Visor de images Gwenview
Name[is]=Gwenview myndskoðari
Name[it]=Visore di immagini Gwenview
Name[ja]=Gwenview 画像ビューア
Name[ka]=Gwenview - სურათების დამთვალიერებელი
Name[kk]=Gwenview кескінді қарау құралы
Name[km]=កម្មវិធី​មើល​រូបភាព​របស់ Gwenview
Name[ko]=Gwenview 그림 뷰어
Name[ku]=Gwenview Nîşanderê Wêneyan
Name[lt]=Gwenview paveikslų žiūryklė
Name[lv]=„Gwenview“ attēlu skatītājs
Name[ml]=ഗ്വെൻവ്യൂ ചിത്രദര്‍ശിനി
Name[mr]=ग्वेनव्यु प्रतिमा प्रदर्शक
Name[nb]=Bildeviseren Gwenview
Name[nds]=Bildkieker Gwenview
Name[ne]=जीवेनभ्यू छवि दर्शक
Name[nl]=GWenview Afbeeldingenviewer
Name[nn]=Gwenview biletvisar
Name[pa]=ਗਵਿਨ-ਵਿਊ ਚਿੱਤਰ ਦਰਸ਼ਕ
Name[pl]=Przeglądarka obrazów Gwenview
Name[pt]=Visualizador de Imagens Gwenview
Name[pt_BR]=Visualizador de imagens Gwenview
Name[ro]=Vizualizator de imagini KView
Name[ru]=Просмотр изображений в Gwenview
Name[sa]=ग्वेनव्यू इमेज दर्शक
Name[si]=Gwenview පිංතූර දසුන
Name[sk]=Prehliadač obrázkov Gwenview
Name[sl]=Pregledovalnik slik Gwenview
Name[sr]=Гвенвју приказивач слика
Name[sr@ijekavian]=Гвенвју приказивач слика
Name[sr@ijekavianlatin]=GwenView prikazivač slika
Name[sr@latin]=GwenView prikazivač slika
Name[sv]=Gwenview bildvisare
Name[ta]=குவென்வியூ படக் காட்டி
Name[th]=เกวนวิว - เครื่องมือแสดงภาพ
Name[tr]=Gwenview Görsel Görüntüleyicisi
Name[ug]=Gwenview سۈرەت كۆرگۈ
Name[uk]=Переглядач зображень Gwenview
Name[vi]=Bộ xem ảnh Gwenview
Name[zh_CN]=Gwenview 图像查看器
Name[zh_TW]=Gwenview 影像檢視程式
MimeType=${IMAGE_MIME_TYPES};
X-KDE-ServiceTypes=KParts/ReadOnlyPart
X-KDE-Library=kf6/parts/gvpart
InitialPreference=12
Icon=gwenview

==> gwenview-25.11.80.tar.xz: gwenview-25.11.80/part/gvpart.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Gwenview Image Viewer
Name[ar]=جوِينفيو مستعرض الصورة
Name[az]=Gwenview Şəkilə Baxış Vasitəsi
Name[be]=Праграма для прагляду выяў Gwenview
Name[bg]=Програма за снимки Gwenview
Name[bs]=Gvenview prikazivač slika
Name[ca]=Visualitzador d'imatges Gwenview
Name[ca@valencia]=Visor d'imatges Gwenview
Name[cs]=Prohlížeč obrázků Gwenview
Name[da]=Gwenview billedfremviser
Name[de]=Gwenview Bildbetrachter
Name[el]=Προβολέας εικόνων Gwenview
Name[en_GB]=Gwenview Image Viewer
Name[eo]=Gwenview Bildrigardilo
Name[es]=Visor de imágenes Gwenview
Name[et]=Gwenview pildinäitaja
Name[eu]=Gwenview irudi erakuslea
Name[fa]=مشاهده‌گر تصویر گوئن‌ویو
Name[fi]=Gwenview-kuvankatselin
Name[fr]=Afficheur d'images Gwenview
Name[ga]=Amharcán Íomhánna Gwenview
Name[gl]=Visor de imaxes Gwenview
Name[he]=מציג התמונות Gwenview
Name[hi]=ग्वेन-व्यू छवि प्रदर्शक
Name[hne]=ग्वेन-व्यू फोटू प्रदर्सक
Name[hr]=Preglednik slika Gwenview
Name[hsb]=Gwenview wobhladowar za wobrazy
Name[hu]=Gwenview képnézegető
Name[ia]=Visor de imagine Gwenview
Name[id]=Penampil Citra Gwenview
Name[ie]=Visor de images Gwenview
Name[is]=Gwenview myndskoðari
Name[it]=Visore di immagini Gwenview
Name[ja]=Gwenview 画像ビューア
Name[ka]=Gwenview - სურათების დამთვალიერებელი
Name[kk]=Gwenview кескінді қарау құралы
Name[km]=កម្មវិធី​មើល​រូបភាព​របស់ Gwenview
Name[ko]=Gwenview 그림 뷰어
Name[ku]=Gwenview Nîşanderê Wêneyan
Name[lt]=Gwenview paveikslų žiūryklė
Name[lv]=„Gwenview“ attēlu skatītājs
Name[ml]=ഗ്വെൻവ്യൂ ചിത്രദര്‍ശിനി
Name[mr]=ग्वेनव्यु प्रतिमा प्रदर्शक
Name[nb]=Bildeviseren Gwenview
Name[nds]=Bildkieker Gwenview
Name[ne]=जीवेनभ्यू छवि दर्शक
Name[nl]=GWenview Afbeeldingenviewer
Name[nn]=Gwenview biletvisar
Name[pa]=ਗਵਿਨ-ਵਿਊ ਚਿੱਤਰ ਦਰਸ਼ਕ
Name[pl]=Przeglądarka obrazów Gwenview
Name[pt]=Visualizador de Imagens Gwenview
Name[pt_BR]=Visualizador de imagens Gwenview
Name[ro]=Vizualizator de imagini KView
Name[ru]=Просмотр изображений в Gwenview
Name[sa]=ग्वेनव्यू इमेज दर्शक
Name[si]=Gwenview පිංතූර දසුන
Name[sk]=Prehliadač obrázkov Gwenview
Name[sl]=Pregledovalnik slik Gwenview
Name[sr]=Гвенвју приказивач слика
Name[sr@ijekavian]=Гвенвју приказивач слика
Name[sr@ijekavianlatin]=GwenView prikazivač slika
Name[sr@latin]=GwenView prikazivač slika
Name[sv]=Gwenview bildvisare
Name[ta]=குவென்வியூ படக் காட்டி
Name[th]=เกวนวิว - เครื่องมือแสดงภาพ
Name[tr]=Gwenview Görsel Görüntüleyicisi
Name[ug]=Gwenview سۈرەت كۆرگۈ
Name[uk]=Переглядач зображень Gwenview
Name[vi]=Bộ xem ảnh Gwenview
Name[zh_CN]=Gwenview 图像查看器
Name[zh_TW]=Gwenview 影像檢視程式
MimeType=${IMAGE_MIME_TYPES};
X-KDE-ServiceTypes=KParts/ReadOnlyPart
X-KDE-Library=kf6/parts/gvpart
InitialPreference=12
Icon=gwenview
